/*
   Copyright 2012 YuGiOhJCJ.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
   */
#include "BatteryMonitor.h"
#include <QString>
#include <QStringList>
#include <QFile>
BatteryMonitor::BatteryMonitor()
{
	this->update();
	this->qlabel.setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
	this->qvboxlayout.addWidget(&(this->qlabel));
	this->setLayout(&(this->qvboxlayout));
	this->qtimer.start(1000);
	connect(&qtimer, SIGNAL(timeout()), this, SLOT(update()));
}
QString BatteryMonitor::getCurValue()
{
	QFile qfile;
	QStringList qstr_lst;
	QString qstr_cur;
	char str_cur[1024];
	qfile.setFileName("/proc/acpi/battery/BAT0/state");
	if(qfile.open(QIODevice::ReadOnly | QIODevice::Text) == false)
	{
		return "";
	}
	while(qfile.read(str_cur, 1024) > 0)
	{
		qstr_cur.remove(0, qstr_cur.size());
		qstr_cur.append(str_cur);
		if(qstr_cur.contains("remaining capacity:") == true)
		{
			break;
		}
	}
	qfile.close();
	qstr_lst.clear();
	qstr_lst.append(qstr_cur.split(QString("remaining capacity:")));
	qstr_cur = qstr_lst.value(1);
	qstr_lst.clear();
	qstr_lst.append(qstr_cur.split(QString("mAh")));
	qstr_cur = qstr_lst.value(0);
	return qstr_cur;
}
QString BatteryMonitor::getMaxValue()
{
	QFile qfile;
	QStringList qstr_lst;
	QString qstr_max;
	char str_max[1024];
	qfile.setFileName("/proc/acpi/battery/BAT0/info");
	if(qfile.open(QIODevice::ReadOnly | QIODevice::Text) == false)
	{
		return "";
	}
	while(qfile.read(str_max, 1024) > 0)
	{
		qstr_max.remove(0, qstr_max.size());
		qstr_max.append(str_max);
		if(qstr_max.contains("last full capacity:") == true)
		{
			break;
		}
	}
	qfile.close();
	qstr_lst.clear();
	qstr_lst.append(qstr_max.split(QString("last full capacity:")));
	qstr_max = qstr_lst.value(1);
	qstr_lst.clear();
	qstr_lst.append(qstr_max.split(QString("mAh")));
	qstr_max = qstr_lst.value(0);
	return qstr_max;
}
QString BatteryMonitor::getPercentage()
{
	int int_cur;
	int int_max;
	int int_percentage;
	QString qstr_cur(this->getCurValue());
	QString qstr_max(this->getMaxValue());
	int_cur = qstr_cur.toInt();
	int_max = qstr_max.toInt();
	if(int_max == 0)
	{
		int_percentage = 0;
	}
	else
	{
		int_percentage = (int_cur * 100) / int_max;
	}
	return QString::number(int_percentage, 10);
}
int BatteryMonitor::update()
{
	QString qstr_percentage(this->getPercentage());
	this->qlabel.setText("Battery: "+qstr_percentage+"% remaining");
	return 0;
}
